import unittest

from mock import patch, MagicMock

import smssluzbacz_api.post
from smssluzbacz_api import TelephoneNumberError, MessageError, ActionError, LoginError, CreditError,\
    GateError


class TestSmsGateApiPost(unittest.TestCase):

    def setUp(self):
        self.response_mock = MagicMock()
        self.response_mock.status_code = None
        self.response_mock.text = ''

    def test_non_200_response_code(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 1000
            with self.assertRaises(GateError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', 'message')

    def test_telephone_number_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(TelephoneNumberError.code)
            with self.assertRaises(TelephoneNumberError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('12345-6789', 'message')

    def test_message_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(MessageError.code)
            with self.assertRaises(MessageError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', '')

    def test_action_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(ActionError.code)
            with self.assertRaises(ActionError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', 'message')

    def test_login_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(LoginError.code)
            with self.assertRaises(LoginError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', 'message')

    def test_credit_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(CreditError.code)
            with self.assertRaises(CreditError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', 'message')

    def test_gate_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>{0}</id><message></message></status>'.format(GateError.code)
            with self.assertRaises(GateError):
                api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
                api.send('123456789', 'message')

    def test_no_error(self):
        with patch('smssluzbacz_api.post.requests') as mock:
            mock.post.return_value = self.response_mock
            self.response_mock.status_code = 200
            self.response_mock.text = '<status><id>200</id><message></message></status>'
            api = smssluzbacz_api.post.SmsGateApi('login', 'pass')
            result = api.send('123456789', 'message')
            self.assertTrue(result)


if __name__ == '__main__':
    unittest.main()


import logging
from hashlib import md5
from xml.dom.minidom import parseString

import requests

from smssluzbacz_api import TelephoneNumberError, MessageError, ActionError, LoginError, CreditError, \
    GateError, TRUNCATE_LIMIT, USER_AGENT


log = logging.getLogger(__name__)


class SmsGateApi(object):
    """Implements 'POST' version of sms.sluzba.cz HTTP API.

    Implements simple XML response protocol and uses advanced tokenized
    authentication.

    """

    ACTION_SEND = 'send'
    URL = 'http://smsgateapi.sluzba.cz/apipost20/sms'
    URL_SSL = 'https://smsgateapi.sluzba.cz/apipost20/sms'

    def __init__(self, login, password, timeout=2, use_ssl=True):
        """Initializes SmsGateApi class.

        :param login: sms.sluzba.cz login
        :type login: string
        :param password: password to sms.sluzba.cz
        :type password: string
        :param timeout: http connection timeout in seconds
        :type timeout: int
        :param use_ssl: whether to use ssl via http or not
        :rtype use_ssl: bool
        :returns: SmsGateApi instance
        :rtype: smssluzbacz_api.post.SmsGateApi

        """
        self.login = login
        self.password = password
        self.timeout = timeout
        self.use_ssl = use_ssl

    def send(self, tel_number, message):
        """Sends SMS via sms.sluzba.cz.

        :param tel_number: telephone number of SMS receiver
        :type tel_number: string
        :param message: text body of SMS
        :type message: string
        :returns: True is SMS was successfully sent
        :rtype: bool
        :raises: ValueError, urllib2.URLError, urllib2.HTTPError, GateError
        :raises: TelephoneNumberError, MessageError, ActionError, LoginError
        :raises: CreditError

        """
        if message is not None and len(message) > TRUNCATE_LIMIT:
            log.warn('Message text exceeds %d characters and will be automatically truncated', TRUNCATE_LIMIT)
        params = (
            ('msg', message),
            ('msisdn', tel_number),
            ('act', SmsGateApi.ACTION_SEND),
            ('login', self.login),
            ('auth', self.__get_auth_key(message))
        )
        log.debug('Post params built: %s', params)
        log.info('Sending SMS to number: %s, message text: %s', tel_number, message)
        response = requests.post(SmsGateApi.URL_SSL if self.use_ssl else SmsGateApi.URL, data=dict(params),
                                 headers={'User-Agent': USER_AGENT, 'Accept': 'text/plain'}, timeout=self.timeout)
        if response.status_code != 200:
            raise GateError
        dom = parseString(response.text)
        code = dom.getElementsByTagName('id')[0].childNodes[0].data
        if code == TelephoneNumberError.code:
            raise TelephoneNumberError
        elif code == MessageError.code:
            raise MessageError
        elif code == ActionError.code:
            raise ActionError
        elif code == LoginError.code:
            raise LoginError
        elif code == CreditError.code:
            raise CreditError
        elif code == GateError.code:
            raise GateError
        elif code == '200':
            log.info('SMS message successfully sent to %s.', tel_number)
            return True

    def __get_auth_key(self, message):
        return md5(md5(self.password).hexdigest() + self.login + SmsGateApi.ACTION_SEND + message[:31]).hexdigest()


import re
import logging
import urllib

import requests

from smssluzbacz_api import TelephoneNumberError, MessageError, ActionError, LoginError, CreditError,\
    GateError, TRUNCATE_LIMIT, USER_AGENT


log = logging.getLogger(__name__)


__all__ = ['SmsGateApi']


class SmsGateApi(object):
    """Implements 'Lite' version of sms.sluzba.cz HTTP API.

    The only possibility of lite version is to send POST/GET request to send SMS
    with no advanced options and operations.

    """
    URL = 'http://smsgateapi.sluzba.cz/apilite20/sms'
    URL_SSL = 'https://smsgateapi.sluzba.cz/apilite20/sms'

    def __init__(self, login, password, timeout=2, use_ssl=True):
        """Initializes SmsGateApi class.

        :param login: sms.sluzba.cz login
        :type login: string
        :param password: password to sms.sluzba.cz
        :type password: string
        :param timeout: http connection timeout in seconds
        :type timeout: int
        :param use_ssl: whether to use ssl via http or not
        :type use_ssl: bool
        :returns: SmsGateApi instance
        :rtype: smssluzbacz_api.lite.SmsGateApi

        """
        self.login = login
        self.password = password
        self.timeout = timeout
        self.use_ssl = use_ssl

    def send(self, tel_number, message, use_post=True):
        """Sends SMS via sms.sluzba.cz.

        :param tel_number: telephone number of SMS receiver
        :type tel_number: string
        :param message: text body of SMS
        :type message: string
        :param use_post: whether to use GET or POST http method
        :type use_post: bool
        :returns: True is SMS was successfully sent
        :rtype: bool
        :raises: ValueError, urllib2.URLError, urllib2.HTTPError, GateError
        :raises: TelephoneNumberError, MessageError, ActionError, LoginError
        :raises: CreditError

        """
        if message is not None and len(message) > TRUNCATE_LIMIT:
            log.warn('Message text exceeds %d characters and will be automatically truncated', TRUNCATE_LIMIT)
        params = (
            ('login', self.login),
            ('password', self.password),
            ('number', tel_number),
            ('text', message)
        )
        log.debug('Params built: %s', params)
        log.info('Sending SMS to number: %s, message text: %s', tel_number, message)
        if use_post:
            response = requests.post(SmsGateApi.URL_SSL if self.use_ssl else SmsGateApi.URL, data=dict(params),
                                     headers={'User-Agent': USER_AGENT, 'Accept': 'text/plain'},
                                     timeout=self.timeout)
        else:
            encoded_params = urllib.urlencode(params)
            if self.use_ssl:
                encoded_url = '?'.join([SmsGateApi.URL_SSL, encoded_params])
            else:
                encoded_url = '?'.join([SmsGateApi.URL, encoded_params])
            response = requests.get(encoded_url, headers={'User-Agent': USER_AGENT}, timeout=self.timeout)
        if response.status_code != 200:
            raise GateError
        if re.match(r'^{0}'.format(TelephoneNumberError.code), response.text) is not None:
            raise TelephoneNumberError
        elif re.match(r'^{0}'.format(MessageError.code), response.text) is not None:
            raise MessageError
        elif response.text[:3] == ActionError.code:
            raise ActionError
        elif response.text[:3] == LoginError.code:
            raise LoginError
        elif response.text[:3] == CreditError.code:
            raise CreditError
        elif response.text[:3] == GateError.code:
            raise GateError
        elif response.text[:3] == '200':
            log.info('SMS message successfully sent to %s.', tel_number)
            return True


__version__ = '1.1'

import logging


log = logging.getLogger(__name__)


__all__ = [
    '__version__', 'TRUNCATE_LIMIT', 'USER_AGENT', 'Error', 'TelephoneNumberError', 'MessageError',
    'ActionError', 'LoginError', 'CreditError', 'GateError'
]


TRUNCATE_LIMIT = 459
USER_AGENT = 'python-smssluzba-cz'


class Error(Exception):
    """Base Error class for all package errors."""

    def __init__(self):
        super(Error, self).__init__(getattr(self, 'code'), getattr(self, 'message'))


class TelephoneNumberError(Error):

    code = '400;1'
    message = 'Telephone number is invalid.'


class MessageError(Error):

    code = '400;2'
    message = 'Message is empty.'


class ActionError(Error):

    code = '400'
    message = 'Unknown action.'


class LoginError(Error):

    code = '401'
    message = 'Invalid login credentials.'


class CreditError(Error):

    code = '402'
    message = 'Insufficient credit in your account.'


class GateError(Error):

    code = '503'
    message = 'SMS gate intercepted unknown error.'


# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import smssluzbacz_api
import os


def read(fname):
    """Utility function to read the README file.

    Used for the long_description. It's nice, because now 1) we have a top level
    README file and 2) it's easier to type in the README file than to put a raw
    string in below ...

    """
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='smssluzbacz-api',
    version=smssluzbacz_api.__version__,
    description='api library for sending SMS (shor text message) via sms.sluzba.cz service',
    long_description=read('README.rst'),
    author=u'Vladimír Gorej, Jozef Ševčík',
    author_email='info@codescale.net',
    url='http://www.codescale.net/en/community#smssluzbacz-api',
    download_url='https://github.com/jsk/python-smssluzbacz-api/tarball/master',
    license='BSD',
    keywords = 'sms api',
    packages=find_packages(),
    platforms='any',
    install_requires=['requests'],
    tests_require=['mock'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities'
    ],
    test_suite='smssluzbacz_api.test'
)


import unittest

from smssluzbacz_api.test import test_lite_api, test_post_api


if __name__ == "__main__":
    loader = unittest.TestLoader()
    suite = unittest.TestSuite()
    suite.addTest(loader.loadTestsFromModule(test_lite_api))
    suite.addTest(loader.loadTestsFromModule(test_post_api))
    unittest.TextTestRunner(verbosity=2).run(suite)


import argparse
from smssluzbacz_api.post import SmsGateApi


parser = argparse.ArgumentParser(description='Processes login, password and receiver telephone number')
parser.add_argument('login', metavar='login', type=str, help='sms.sluzba.cz login')
parser.add_argument('password', metavar='password', type=str, help='sms.sluzba.cz password')
parser.add_argument('tel_number', metavar='tel_number', type=str, help='number of SMS receiver')
parser.add_argument('--use-ssl', action='store_true', help='whether to use ssl over HTTP', default=False,
                    required=False)
parser.add_argument('--timeout', metavar='timeout', type=float, help='http connection timeout', default=2,
                    required=False)
args = vars(parser.parse_args())

api = SmsGateApi(args['login'], args['password'], args['timeout'], args['use_ssl'])
api.send(args['tel_number'], 'test SMS message')